<?php

namespace Wp618\Login;

if ( !defined( 'ABSPATH' ) ) exit;

//
class Setup
{
    //
    private $app;

    //
    public function __construct(){
        $this->app = App::getInstance();
    }

    //
    public function load_setup(){
        if($this->app->get_is_actived()){
            $option = 'general';
            $data = $this->get_setup_data($option);
            $this->app->display($option, $data);
        }else{
            $action = get_action('app_active');
            $data = [
                'action' => $action,
                'nonce' => \wp_create_nonce($action),
                'option' => 'none',
            ];

            $this->app->display('active', $data);
        }
    }

    //
    public function loglog(){
        $ip = $this->app->request->get('ip', 'striptags', '');
        $page = $this->app->request->get('page', 'wdash', '');
        $paged = $this->app->request->get('paged', 'absint', 1);
        $paged = max(1, $paged);

        $per_page = 20;

        $query = [
            'order' => 'id desc',
            'offset' => $per_page * ($paged - 1),
            'limit' => $per_page,
        ];

        if(strlen($ip)){
            $query['where'] = ['ip' => $ip];
        }

        $total = $this->app->visitor_model->get_count($query);

        $paging = new Paging();
        $paging->set_args($total, $per_page);

        $list = $this->app->visitor_model->get_all($query);

        $action = get_action('delete_more_log');
        $nonce = \wp_create_nonce($action);

        $this->app->display('log', [
            'per_page' => $per_page,
            'paged' => $paged,
            'total' => $total,
            'list' => $list,
            'paging' => $paging,
            'action' => $action,
            'nonce' => $nonce,
            'page' => $page,
        ]);
    }

    //
    private function get_setup_data($option){
        $config = get_app_config();
        $set = $this->get_render_items($option, $config);

        $action = get_action('setup_save');

        $data = [
            'action' => $action,
            'nonce' => \wp_create_nonce($action),
            'option' => $option,
            'set' => $set,
        ];

        return $data;
    }

    //
    private function get_render_items($option, $config){
        if(isset($config[$option])){
            return $config[$option];
        }

        $list = [];

        if(isset(Constant::SETUP_FIELDS[$option])){
            foreach (Constant::SETUP_FIELDS[$option] as $name => $val){
                $list[$name] = $val[1];
            }
        }

        return $list;
    }
}